/* GNOME-Mud - A simple Mud CLient
 * Copyright (C) 1999-2001 Robin Ericsson <lobbin@localhost.nu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <gconf/gconf-client.h>
#include <gtk/gtk.h>
#include <libintl.h>
#include <stdio.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <pwd.h>
#include <glade/glade-xml.h>

#include <gdk/gdkkeysyms.h>

#include "gnome-mud.h"
#include "directions.h"

#define _(string)	gettext(string)

extern SYSTEM_DATA  prefs;
extern GConfClient	*gconf_client;

GladeXML *window_directions_xml;
	
/* directions.c */

static void directions_gconf_sync(PROFILE_DATA *pd)
{
	gchar *pname = gconf_escape_key(pd->name, -1);
	gchar *key = g_strdup_printf("/apps/gnome-mud/profiles/%s/directions", pname);

	gconf_client_set_list(gconf_client, key, GCONF_VALUE_STRING, pd->directions, NULL);

	g_free(key);
	g_free(pname);
}

void directions_window_ok_cb(GtkButton *button, gpointer user_data) {
	PROFILE_DATA *pd = (PROFILE_DATA *) user_data;
	gchar *s;
	
	g_message("Directions ok callback");
	
	g_slist_free(pd->directions);
	pd->directions=NULL;
	//Store values
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"nentry"))));
	g_message("Storing \"%s\"\n",s);
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"neentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"eentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"seentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"sentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"swentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"wentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"nwentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"upentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"downentry"))));
	pd->directions=g_slist_append(pd->directions,s);
	s=g_strdup(gtk_entry_get_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"lookentry"))));
	pd->directions=g_slist_append(pd->directions,s);

	directions_gconf_sync(pd);
	gtk_widget_destroy(glade_xml_get_widget(window_directions_xml,"directionswindow"));
}

void directions_window_cancel_cb(GtkButton *button, gpointer user_data) {
	g_message("Directions cancel callback");

	gtk_widget_destroy(glade_xml_get_widget(window_directions_xml,"directionswindow"));
}

void window_directions(PROFILE_DATA *pd) 
{
	gchar *path;

	path = g_strconcat(PKGDATADIR,"/directions.glade",NULL);
	window_directions_xml = glade_xml_new(path,NULL,NULL);
	g_free(path);

	glade_xml_signal_connect_data(window_directions_xml,"directions_window_ok_cb",G_CALLBACK(directions_window_ok_cb),pd);
	glade_xml_signal_connect_data(window_directions_xml,"directions_window_cancel_cb",G_CALLBACK(directions_window_cancel_cb),pd);
	//Set values
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"nentry")),
			g_slist_nth_data(pd->directions,DIRECTION_NORTH));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"neentry")),
			g_slist_nth_data(pd->directions,DIRECTION_NORTHEAST));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"eentry")),
			g_slist_nth_data(pd->directions,DIRECTION_EAST));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"seentry")),
			g_slist_nth_data(pd->directions,DIRECTION_SOUTHEAST));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"sentry")),
			g_slist_nth_data(pd->directions,DIRECTION_SOUTH));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"swentry")),
			g_slist_nth_data(pd->directions,DIRECTION_SOUTHWEST));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"wentry")),
			g_slist_nth_data(pd->directions,DIRECTION_WEST));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"nwentry")),
			g_slist_nth_data(pd->directions,DIRECTION_NORTHWEST));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"upentry")),
			g_slist_nth_data(pd->directions,DIRECTION_UP));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"downentry")),
			g_slist_nth_data(pd->directions,DIRECTION_DOWN));
	gtk_entry_set_text(GTK_ENTRY(glade_xml_get_widget(window_directions_xml,"lookentry")),
			g_slist_nth_data(pd->directions,DIRECTION_LOOK));
}

